import numpy as np


def ODE_TM(theta, S, GAMMA):

    # numpy or other python packages don't readily contain cot() function
    cot = np.cos(theta) / np.sin(theta)

    # Constant
    a = (GAMMA - 1) / 2

    # Taylor-Maccoll
    # Ref. J. Anderson, Modern Compressible Flow with Historical Perspective 3rd Ed.
    nom   = (S[0] * S[1] ** 2) - a * (1 - S[0] ** 2 - S[1] ** 2) * (2 * S[0] + S[1] * cot)
    denom = a * (1 - S[0] ** 2 - S[1] ** 2) - S[1] ** 2

    # Expression for the ODE System
    dVr = S[1]
    dVtheta = nom / denom

    return np.array([dVr, dVtheta])
