import numpy as np


def RK4_TM(F, StartingValue, EVENT, step, S0, condition, GAMMA):

    theta          = StartingValue       # theta variable will be continuously updated
    STEPS          = StartingValue       # STEPS variable will be continuously appended -> vector
    q_state        = np.zeros((1, 2))    # Initializing State Vector variable
    q_state[-1, :] = S0                  # Initial Condition
    Crit           = 1                   # Initializing controlling variable

    while Crit > EVENT:  # March until V_theta == 0

        # Obtaining RK4 Coefficients
        F1         = F(theta, q_state[-1, :], GAMMA)
        F2         = F(theta + (step / 2), q_state[-1, :] + (step / 2) * F1, GAMMA)
        F3         = F(theta + (step / 2), q_state[-1, :] + (step / 2) * F2, GAMMA)
        F4         = F(theta + step, q_state[-1, :] + step * F3, GAMMA)

        # Next step
        q_state    = np.vstack((q_state, (q_state[-1, :] + (step / 6) * (F1 + (2 * F2) + (2 * F3) + F4))))

        # Updating variables
        theta      = theta + step
        STEPS      = np.append(STEPS, theta)
        Crit       = -(q_state[-1, 1])

    # Modifying output
    if condition == "True":
        return [q_state, STEPS]
    else:
        return q_state
